# -------------------------------------------------------------------------- #
# Copyright 2002-2009, Distributed Systems Architecture Group, Universidad   #
# Complutense de Madrid (dsa-research.org)                                   #
#                                                                            #
# Licensed under the Apache License, Version 2.0 (the "License"); you may    #
# not use this file except in compliance with the License. You may obtain    #
# a copy of the License at                                                   #
#                                                                            #
# http://www.apache.org/licenses/LICENSE-2.0                                 #
#                                                                            #
# Unless required by applicable law or agreed to in writing, software        #
# distributed under the License is distributed on an "AS IS" BASIS,          #
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   #
# See the License for the specific language governing permissions and        #
# limitations under the License.                                             #
#--------------------------------------------------------------------------- #

Name: opennebula
Summary: Cloud computing solution for Data Center Virtualization
Version: 3.8.1
Release: 1
License: Apache
Group: System
URL: http://opennebula.org

Source0: opennebula-3.8.1.tar.gz
Patch0: legacy_sinatra.diff

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: gcc-c++
BuildRequires: libcurl-devel
BuildRequires: libxml2-devel
BuildRequires: xmlrpc-c-devel
BuildRequires: openssl-devel
BuildRequires: mysql-devel
BuildRequires: openssh
BuildRequires: pkgconfig
BuildRequires: ruby
BuildRequires: scons
BuildRequires: sqlite-devel
BuildRequires: xmlrpc-c
BuildRequires: java-1.7.0-openjdk-devel

Requires: openssl
Requires: ruby
Requires: openssh
Requires: sqlite
Requires: xmlrpc-c
Requires: rubygems
Requires: wget
Requires: curl

Requires: rubygem-sqlite3-ruby
Requires: rubygem-json
Requires: rubygem-rack
Requires: rubygem-sinatra
Requires: rubygem-thin
Requires: rubygem-sequel
Requires: rubygem-uuidtools
Requires: rubygem-nokogiri

# Missing gems
# amazon-ec2
# curb
# net-ldap

Packager: OpenNebula Team <contact@opennebula.org>

%description
OpenNebula.org is an open-source project aimed at building the industry
standard open source cloud computing tool to manage the complexity and
heterogeneity of distributed data center infrastructures.

The OpenNebula.org Project is maintained and driven by the community. The
OpenNebula.org community has thousands of users, contributors, and supporters,
who interact through various online email lists, blogs and innovative projects
to support each other.

OpenNebula is free software released under the Apache License.

%package java
Summary: Java interface to OpenNebula Cloud API
Group:   System

%description java
Java interface to OpenNebula Cloud API

%package sunstone
Summary: Browser based UI for administrating a OpenNebula cloud
Requires: opennebula

%description sunstone
Web UI for OpenNebula

%prep
%setup -q
%patch0 -p1

%build
scons -j2 mysql=yes
cd src/oca/java
./build.sh -d

%install
export DESTDIR=%{buildroot}
./install.sh
%{__mkdir} -p %{buildroot}%{_initddir}
install -p -D -m 755 share/pkgs/CentOS/opennebula %{buildroot}/%{_initddir}/opennebula
install -p -D -m 755 share/pkgs/CentOS/opennebula-sunstone %{buildroot}/%{_initddir}/opennebula-sunstone
install -p -D -m 755 share/pkgs/CentOS/opennebula-occi %{buildroot}/%{_initddir}/opennebula-occi
install -p -D -m 644 src/oca/java/jar/org.opennebula.client.jar %{buildroot}%{_javadir}/org.opennebula.client.jar

%clean
%{__rm} -rf %{buildroot}

%pre
#%{__mkdir} -p %{_sysconfdir}/one
#%{__mkdir} -p /usr/lib/one
#%{__mkdir} -p /usr/share/one
#%{__mkdir} -p /var/lock/one
#%{__mkdir} -p /var/log/one
#%{__mkdir} -p /var/run/one

getent group oneadmin >/dev/null || groupadd -r oneadmin
if ! grep -q oneadmin %{_sysconfdir}/passwd
then
    /usr/sbin/useradd -r -m -d /var/lib/one -g oneadmin -s /bin/bash oneadmin 2> /dev/null
else
    /usr/bin/gpasswd -a oneadmin oneadmin > /dev/null
fi

%post
if [ $1 = 1 ]; then
    /sbin/chkconfig --add opennebula >/dev/null
    if [ ! -e /var/lib/one/.one/one_auth ]; then
        PASSWORD=$(echo $RANDOM$(date '+%s')|md5sum|cut -d' ' -f1)
        mkdir -p /var/lib/one/.one
        echo oneadmin:$PASSWORD > /var/lib/one/.one/one_auth
        /bin/chown -R oneadmin:oneadmin /var/lib/one/.one
    fi
fi

%preun
if [ $1 = 0 ]; then
    /sbin/service opennebula stop >/dev/null
    /sbin/chkconfig --del opennebula >/dev/null
fi

%files java
%defattr(-,root,root)
%{_javadir}/org.opennebula.client.jar

%files sunstone
%defattr(0640, root, oneadmin, -)
%config /etc/one/sunstone-server.conf
%config /etc/one/sunstone-plugins.yaml

%defattr(-, root, root, 0755)
/usr/lib/one/sunstone/*
%{_bindir}/sunstone-server
%{_initddir}/opennebula-sunstone

%files
%defattr(0640, root, oneadmin, 0750)
%dir %{_sysconfdir}/one
%config /etc/one/occi-server.conf
%config /etc/one/defaultrc
%config /etc/one/oned.conf
%config /etc/one/ec2query_templates/m1.small.erb
%config /etc/one/occi_templates/large.erb
%config /etc/one/occi_templates/small.erb
%config /etc/one/occi_templates/custom.erb
%config /etc/one/occi_templates/medium.erb
%config /etc/one/occi_templates/common.erb
%config /etc/one/occi_templates/network.erb
%config /etc/one/vmm_exec/vmm_execrc
%config /etc/one/vmm_exec/vmm_exec_vmware.conf
%config /etc/one/vmm_exec/vmm_exec_kvm.conf
%config /etc/one/vmm_exec/vmm_exec_xen.conf
%config /etc/one/group.default
%config /etc/one/ozones-server.conf
%config /etc/one/cli/onehost.yaml
%config /etc/one/cli/onecluster.yaml
%config /etc/one/cli/oneuser.yaml
%config /etc/one/cli/onevnet.yaml
%config /etc/one/cli/oneacct.yaml
%config /etc/one/cli/onetemplate.yaml
%config /etc/one/cli/oneacl.yaml
%config /etc/one/cli/onedatastore.yaml
%config /etc/one/cli/onegroup.yaml
%config /etc/one/cli/oneimage.yaml
%config /etc/one/cli/onevm.yaml
%config /etc/one/sched.conf
%config /etc/one/im_ec2/im_ec2rc
%config /etc/one/im_ec2/im_ec2.conf
%config /etc/one/vmwarerc
%config /etc/one/auth/x509_auth.conf
%config /etc/one/auth/ldap_auth.conf
%config /etc/one/auth/server_x509_auth.conf
%config /etc/one/hm/hmrc
%config /etc/one/econe.conf
%config /etc/one/vmm_ec2/vmm_ec2rc
%config /etc/one/vmm_ec2/vmm_ec2.conf

%defattr(-, root, root, 0755)
%{_initddir}/opennebula
%{_initddir}/opennebula-occi

%{_bindir}/eco*
%{_bindir}/one*
%{_bindir}/occi*
%{_bindir}/mm_sched
%{_bindir}/ozones-server
%{_bindir}/tty_expect

/usr/lib/one/mads/*
/usr/lib/one/ozones/*
/usr/lib/one/ruby/*
/usr/lib/one/sh/*
%doc %{_mandir}/man1/
%doc LICENSE NOTICE

%{_datarootdir}/one/*

%defattr(-, oneadmin, oneadmin, 0750)
%{_sharedstatedir}/one/*

%dir %{_localstatedir}/lock/one
%dir %{_localstatedir}/log/one
%dir %{_localstatedir}/run/one

%changelog
* Fri Oct 26 2012 OpenNebula Team <contact@opennebula.org> - 3.8.1-1
- Adapted the package from Karanbir Singh build:
https://nazar.karan.org/summary/misc!opennebula.git
